<div align="center">

<picture>
  <source srcset="banner-dark.png" media="(prefers-color-scheme: dark)">
  <img src="banner.png">
</picture>

## Companion library for musiccast devices intended for the Home Assistant integration.

[![PyPI Version](https://img.shields.io/pypi/v/aiomusiccast.svg)](https://pypi.org/project/aiomusiccast)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/vigonotion/aiomusiccast)
![Read the Docs](https://img.shields.io/readthedocs/aiomusiccast)
[![PyPI License](https://img.shields.io/pypi/l/aiomusiccast.svg)](https://pypi.org/project/aiomusiccast)


</div>

<br/>

# Setup

## Requirements

* Python 3.8+

## Installation

Install it directly into an activated virtual environment:

```text
$ pip install aiomusiccast
```

or add it to your [Poetry](https://poetry.eustace.io/) project:

```text
$ poetry add aiomusiccast
```

# Usage

After installation, the package can imported:

```text
$ python
>>> import aiomusiccast
>>> aiomusiccast.__version__
```
